// nullmailer -- a simple relay-only MTA
// Copyright (C) 1999  Bruce Guenter <bruceg@em.ca>
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// You can contact me at <bruceg@em.ca>.  There is also a mailing list
// available to discuss this package.  To subscribe, send an email to
// <nullmailer-subscribe@ezmlm.vsource.com>.

#include <config.h>
#include <getopt.h>
#include <stdio.h>
#include <stdlib.h>
#include "connect.h"
#include "errcodes.h"
#include "protocol.h"

bool parse_args(int argc, char* argv[],
		const char*& remote, const char*& filename, int& port)
{
  int ch;
  while((ch = getopt(argc, argv, "p:")) != EOF) {
    switch(ch) {
    case 'p':
      char* end;
      port = strtol(optarg, &end, 0);
      if(port <= 0 || *end != 0)
	return false;
      break;
    default:
      return false;
    }
  }
  if(argc-optind != 2)
    return false;
  remote = argv[optind++];
  filename = argv[optind++];
  return true;
}

int main(int argc, char* argv[])
{
  if(argc < 3)
    return ERR_USAGE;
  const char* remote;
  const char* filename;
  if(!parse_args(argc, argv, remote, filename, port))
    return ERR_USAGE;
  fdibuf in(filename);
  if(!in)
    return ERR_MSG_OPEN;
  int tmp = protocol_prep(&in);
  if(tmp)
    return tmp;
  int fd = tcpconnect(remote, port);
  if(fd < 0)
    return -fd;
  return protocol_send(&in, fd);
}

